@@ -1103,7 +1103,7 @@ class PlaceService(BaseRdbmsService):
 
             # Build the Uniform Resource Locators (URL) of the place's logo and
             # cover photo.
-            place.picture_url = self.build_picture_url(place.picture_url)
+            place.picture_url = self.build_picture_url(place.picture_id)
             place.cover_photo_url = self.build_cover_photo_url(place.cover_photo_id)
 
             # Build the geographical location of the place.
